@@ -2,6 +2,7 @@
 Utility functions for uploading objects.
 """
 
+from os import stat
 from os.path import basename
 from pathlib import Path
 from typing import Optional
@@ -19,18 +20,22 @@ def upload_file(
     id: str,
     namespace: str,
     url: str,
-    input_folder_name: Optional[str] = None,
+    inputs_folder_name: Optional[str] = None,
     flatten_upload_paths: bool = False,
-):
+) -> bool:
     """
     Upload a local file to the YD Object Store using a calculated
     unique upload pathname
     """
 
+    if stat(filename).st_size == 0:
+        print_log(f"Not uploading zero-byte file '{filename}'")
+        return False
+
     dest_filename = unique_upload_pathname(
         filename,
         id=id,
-        input_folder_name=input_folder_name,
+        inputs_folder_name=inputs_folder_name,
         flatten_upload_paths=flatten_upload_paths,
     )
 
@@ -41,12 +46,13 @@ def upload_file(
         namespace=namespace,
         remote_file=dest_filename,
     )
+    return True
 
 
 def unique_upload_pathname(
     filename: str,
     id: str,
-    input_folder_name: Optional[str],
+    inputs_folder_name: Optional[str],
     urlencode_forward_slash: bool = False,
     flatten_upload_paths: bool = False,
 ) -> str:
@@ -68,8 +74,8 @@ def unique_upload_pathname(
     filename = str(double_dots) + "/" + filename if double_dots != 0 else filename
     if urlencode_forward_slash is True:
         filename = filename.replace("/", forward_slash)
-    if input_folder_name is not None:
-        return prefix + input_folder_name + forward_slash + filename
+    if inputs_folder_name is not None:
+        return prefix + inputs_folder_name + forward_slash + filename
     else:
         return prefix + filename
 
